@@ -13,8 +13,6 @@ __version__ = "0.1.9"
 
 import math
 
-import files as gf
-
 
 def dict_sorted(data: dict, flag: int = 0, ascending: bool = True):
     """
@@ -88,18 +86,6 @@ def strips(string: str):
     return string.strip().replace("\n", "").replace("\r", "").replace("\r\n", "")
 
 
-def get_paths_from_dir(dirs: str or list, types: str or list, recusive: bool = False):
-    gf.get_paths_from_dir(dirs, types, recusive)
-
-
-def read_content(file_path: str or PosixPath, encoding: str = "utf-8"):
-    gf.read_content(file_path, encoding)
-
-
-def read_jsons(file_path: str or PosixPath, encoding: str = "utf-8"):
-    gf.read_jsons(file_path, encoding)
-
-
 def remove_0_str(data: list):
     """
     去除list列表中为长度为0的字符串，用于字符串split后，列表中出现长度为0字符串的去除
